<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// M
	'mediabox_description' => 'En mancança, toui lu estac devers li image (embé un atribut type descrivent lou mime/type de l’image) couma pura lu estac embé la classa <code>.mediabox</code> soun enriquit per la bouòta multimedia.

	Es poussible de counfigurà cada estac au cas per cas embé de classa suplementari :

-* <code>boxIframe</code> permete de demandà a durbì l’estac en una bouòta iframe ;

-* <code>boxWidth-350px</code> permete de spechificà una larguessa de 350px per la bouòta ;

-* <code>boxHeight-90pc</code> permete de spechificà una autessa de 90% per la bouòta.

	Un panèu de counfiguracioun vi permete de moudificà lu reglage general a la vouòstra counveniença, couma pura l’aspet de la bouòta tra lu abilhage dispounible.

	Aqueu plugin founciouna soubre lu esquèletrou qu’an una balisa <code>#INSERT_HEAD</code>',
	'mediabox_nom' => 'MediaBox',
	'mediabox_slogan' => 'Bouòta multimedia'
);

?>
